==> eiffelstudio-18.11.10.2592.tar: F_code/C3/ew145.c <==
/*
 * Code for class EW_EIFFEL_SYNTAX_ERROR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew145.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EIFFEL_SYNTAX_ERROR}.make */
void F168_1765 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 167, Current, 0, 1, 1818);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	RTEE;
}

/* {EW_EIFFEL_SYNTAX_ERROR}.summary */
EIF_REFERENCE F168_1766 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("summary", 167, Current, 0, 0, 1819);
	RTGC;
	RTHOOK(1);
	Result = RTMS32_EX_H("S\000\000\000y\000\000\000n\000\000\000t\000\000\000a\000\000\000x\000\000\000 \000\000\000e\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000 \000\000\000i\000\000\000n\000\000\000 \000\000\000",16,2008637984);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4163[Dtype(tr1)-880])(RTCW(tr1));
	if (tb1) {
		RTHOOK(3);
		tr1 = RTMS32_EX_H("A\000\000\000c\000\000\000e\000\000\000",3,4285285);
		F882_5713(RTCW(Result), tr1);
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = RTMS32_EX_H("_\000\000\000U\000\000\000S\000\000\000E\000\000\000_\000\000\000F\000\000\000I\000\000\000L\000\000\000E\000\000\000",9,1469221957);
		tb1 = F880_5626(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(5);
			tr1 = RTMS32_EX_H("\"\000\000\000U\000\000\000s\000\000\000e\000\000\000\"\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000",10,1960902501);
			F882_5713(RTCW(Result), tr1);
		} else {
			RTHOOK(6);
			tr1 = RTMS32_EX_H("c\000\000\000l\000\000\000a\000\000\000s\000\000\000s\000\000\000 \000\000\000",6,1830427424);
			F882_5713(RTCW(Result), tr1);
			RTHOOK(7);
			F882_5713(RTCW(Result), *(EIF_REFERENCE *)(Current));
		}
	}
	RTHOOK(8);
	tr1 = RTMS32_EX_H(" \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000 \000\000\000",9,1997649184);
	F882_5713(RTCW(Result), tr1);
	RTHOOK(9);
	F882_5717(RTCW(Result), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_));
	RTHOOK(10);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit145 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C3/ew145.c <==
/*
 * Code for class EW_EIFFEL_SYNTAX_ERROR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew145.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EIFFEL_SYNTAX_ERROR}.make */
void F168_1765 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 167, Current, 0, 1, 1818);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	RTEE;
}

/* {EW_EIFFEL_SYNTAX_ERROR}.summary */
EIF_REFERENCE F168_1766 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("summary", 167, Current, 0, 0, 1819);
	RTGC;
	RTHOOK(1);
	Result = RTMS32_EX_H("S\000\000\000y\000\000\000n\000\000\000t\000\000\000a\000\000\000x\000\000\000 \000\000\000e\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000 \000\000\000i\000\000\000n\000\000\000 \000\000\000",16,2008637984);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4184[Dtype(RTCW(tr1))-880])(tr1);
	if (tb1) {
		RTHOOK(3);
		tr1 = RTMS32_EX_H("A\000\000\000c\000\000\000e\000\000\000",3,4285285);
		F882_5734(RTCW(Result), tr1);
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = RTMS32_EX_H("_\000\000\000U\000\000\000S\000\000\000E\000\000\000_\000\000\000F\000\000\000I\000\000\000L\000\000\000E\000\000\000",9,1469221957);
		tb1 = F880_5647(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(5);
			tr1 = RTMS32_EX_H("\"\000\000\000U\000\000\000s\000\000\000e\000\000\000\"\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000",10,1960902501);
			F882_5734(RTCW(Result), tr1);
		} else {
			RTHOOK(6);
			tr1 = RTMS32_EX_H("c\000\000\000l\000\000\000a\000\000\000s\000\000\000s\000\000\000 \000\000\000",6,1830427424);
			F882_5734(RTCW(Result), tr1);
			RTHOOK(7);
			F882_5734(RTCW(Result), *(EIF_REFERENCE *)(Current));
		}
	}
	RTHOOK(8);
	tr1 = RTMS32_EX_H(" \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000 \000\000\000",9,1997649184);
	F882_5734(RTCW(Result), tr1);
	RTHOOK(9);
	F882_5738(RTCW(Result), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_));
	RTHOOK(10);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit145 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
